@@ -2,13 +2,13 @@ use strict;
 use warnings;
 package MetaCPAN::API::CPANRatings;
 BEGIN {
-  $MetaCPAN::API::CPANRatings::VERSION = '0.01_01';
+  $MetaCPAN::API::CPANRatings::VERSION = '0.01_02';
 }
 # ABSTRACT: CPAN Ratings information for MetaCPAN::API
 
 use Any::Moose 'Role';
 
-requires 'render_result';
+requires '_http_req';
 
 has cpanratings_prefix => (
     is      => 'ro',
@@ -23,7 +23,7 @@ sub search_cpanratings_exact {
     my $base    = $self->base_url;
     my $prefix  = $self->cpanratings_prefix;
     my $url     = "$base/$prefix/$dist";
-    my $result  = $self->ua->get($url);
+    my $result  = $self->_http_req($url);
 
     return $result;
 }
@@ -35,7 +35,7 @@ sub search_cpanratings_like {
     my $base   = $self->base_url;
     my $prefix = $self->cpanratings_prefix;
     my $url    = "$base/$prefix/_search?q=dist:$dist";
-    my $result = $self->ua->get($url);
+    my $result = $self->_http_req($url);
 
     return $result;
 }
@@ -51,7 +51,7 @@ MetaCPAN::API::CPANRatings - CPAN Ratings information for MetaCPAN::API
 
 =head1 VERSION
 
-version 0.01_01
+version 0.01_02
 
 =head1 AUTHOR
 
